# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .variable import Variable


class ModelMetaResponse(UniversalBaseModel):
    variables: typing.List[Variable]
    type: str
    expected_runs: typing.Optional[typing.List[int]] = None
    expected_hours: typing.Optional[typing.Dict[str, typing.Optional[int]]] = None
    latest_run: typing.Optional[str] = None
    min_date: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
